"""historical manual db changes

Revision ID: 13458b2a631f
Revises: b36825c7869e
Create Date: 2023-01-30 14:49:36.519031
"""

import sqlalchemy as sa
from alembic import op

from indico.core.db.sqlalchemy import UTCDateTime


# revision identifiers, used by Alembic.
revision = '13458b2a631f'
down_revision = 'e787389ca868'
branch_labels = None
depends_on = None


def upgrade():
    # manually added commands
    op.execute('''CREATE SEQUENCE events.proforma_id_seq
            INCREMENT 1
            MINVALUE 5000
            MAXVALUE 9223372036854775807
            START 5000
            CACHE 1;''')
    op.execute('''CREATE SEQUENCE events.invoice_id_seq
            INCREMENT 1
            MINVALUE 1
            MAXVALUE 9223372036854775807
            START 5000
            CACHE 1;''')
    # end of manually added commands

    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        'invoices',
        sa.Column('id', sa.Integer(), server_default=sa.text("nextval('events.invoice_id_seq')"), nullable=False),
        sa.Column('registration_id', sa.Integer(), nullable=False),
        sa.Column('payment_type', sa.Text(), nullable=False),
        sa.Column('amount', sa.Numeric(precision=8, scale=2), nullable=False),
        sa.Column('timestamp', UTCDateTime, nullable=False),
        sa.Column('reg_type', sa.Text(), nullable=True),
        sa.PrimaryKeyConstraint('id', name=op.f('pk_invoices')),
        schema='events'
    )
    op.create_index(op.f('ix_invoices_registration_id'), 'invoices', ['registration_id'], unique=False, schema='events')
    op.create_table(
        'proforma',
        sa.Column('id', sa.Integer(), server_default=sa.text("nextval('events.invoice_id_seq')"), nullable=False),
        sa.Column('registration_id', sa.Integer(), nullable=False),
        sa.Column('payment_type', sa.Text(), nullable=False),
        sa.Column('amount', sa.Numeric(precision=8, scale=2), nullable=False),
        sa.Column('timestamp', UTCDateTime, nullable=False),
        sa.Column('reg_type', sa.Text(), nullable=True),
        sa.PrimaryKeyConstraint('id', name=op.f('pk_proforma')),
        schema='events'
    )
    op.create_index(op.f('ix_proforma_registration_id'), 'proforma', ['registration_id'], unique=False, schema='events')
    op.add_column('registrations', sa.Column('country_vat_name', sa.String(), nullable=True), schema='event_registration')
    op.add_column('registrations', sa.Column('country_vat_number', sa.String(), nullable=True), schema='event_registration')
    op.add_column('registrations', sa.Column('country_vat_rate', sa.Numeric(precision=8, scale=2), nullable=True), schema='event_registration')
    op.add_column('events', sa.Column('invoice_payment', sa.String(), nullable=True), schema='events')
    op.add_column('events', sa.Column('vat_collection_method', sa.String(), nullable=True), schema='events')
    op.add_column('events', sa.Column('country_vat_name', sa.String(), nullable=True), schema='events')
    op.add_column('events', sa.Column('country_vat_number', sa.String(), nullable=True), schema='events')
    op.add_column('events', sa.Column('country_vat_rate', sa.Integer(), nullable=True), schema='events')
    op.add_column('events', sa.Column('external_event_url', sa.String(), nullable=True), schema='events')
    op.add_column('payment_transactions', sa.Column('payment_key', sa.String(), nullable=True), schema='events')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('payment_transactions', 'payment_key', schema='events')
    op.drop_column('events', 'external_event_url', schema='events')
    op.drop_column('events', 'country_vat_rate', schema='events')
    op.drop_column('events', 'country_vat_number', schema='events')
    op.drop_column('events', 'country_vat_name', schema='events')
    op.drop_column('events', 'vat_collection_method', schema='events')
    op.drop_column('events', 'invoice_payment', schema='events')
    op.drop_column('registrations', 'country_vat_rate', schema='event_registration')
    op.drop_column('registrations', 'country_vat_number', schema='event_registration')
    op.drop_column('registrations', 'country_vat_name', schema='event_registration')
    op.drop_index(op.f('ix_proforma_registration_id'), table_name='proforma', schema='events')
    op.drop_table('proforma', schema='events')
    op.drop_index(op.f('ix_invoices_registration_id'), table_name='invoices', schema='events')
    op.drop_table('invoices', schema='events')
    # ### end Alembic commands ###

    # manually added commands
    op.execute('''DROP SEQUENCE events.invoice_id_seq;''')
    op.execute('''DROP SEQUENCE events.proforma_id_seq;''')
    # end of manually added commands
