import re
from decimal import Decimal, ROUND_DOWN

import requests

from indico.core.logger import Logger

logger = Logger.get('exchange_rate')

CZK_EXCHANGE_RATE_URL = ('https://www.cnb.cz/en/financial-markets/foreign-exchange-market/central-bank-exchange-rate'
                         '-fixing/central-bank-exchange-rate-fixing/daily.txt')
CZK_PARSE_REGEX = re.compile(r'.+\|.+\|(.+)\|(.+)\|(\d+\.\d+)', re.MULTILINE)


def retrieve_exchange_rate(base_iso_code='EUR', exchange_iso='CZK'):
    if exchange_iso == 'CZK':
        try:
            result = requests.get(CZK_EXCHANGE_RATE_URL)
        except requests.exceptions.RequestException as e:
            logger.exception(e)
            return Decimal(0.0)
        if result.status_code != 200:
            logger.error(f'Failed to retrieve exchange rate (error code {result.status_code} on retrieval)')
            return Decimal(0.0)
        else:
            rates = {}
            for match in CZK_PARSE_REGEX.finditer(result.text):
                amount = match.group(1)
                code = match.group(2)
                rate = match.group(3)
                rates[code] = {
                    'amount': amount,
                    'rate': rate
                }
            if base_iso_code in rates:
                data = rates[base_iso_code]
                rate = Decimal(data['rate']) / Decimal(data['amount'])
                return rate.quantize(Decimal('.001'), rounding=ROUND_DOWN)
            else:
                logger.error(f'ISO code {base_iso_code} not found')
                return Decimal(0.0)
    else:
        logger.error('Only CZK krona are supported for exchange rate retrieval at present')
        return Decimal(0.0)
